@@ -4,7 +4,7 @@ use Config;
 use File::Spec;
 use JSON::PP qw( encode_json decode_json );
 
-my $status_filename = File::Spec->catfile('_alien', 'probe.json');
+my $status_filename = File::Spec->catfile('_alien', '01probe.json');
 exit if -e $status_filename;
 
 my $archlib = do {
@@ -12,6 +12,7 @@ my $archlib = do {
   die "invoke from makefile" unless $type && $perl && $site;
   $type eq 'perl' ? $perl : $type eq 'site' ? $site : $type eq 'vendor' ? $vendor : die "illegal INSTALLDIRS ($type)";
 };
+$archlib =~ s{\\}{/}g if $^O eq 'MSWin32';
 my @prefix = ($archlib, qw( auto share dist Alien-pkgconf ));
 
 my %status = (
@@ -24,6 +25,9 @@ my %status = (
 
 # These are based on experience in development of PkgConfig.pm:
 
+$status{system_libdir}     = ['/usr/lib'];
+$status{system_includedir} = ['/usr/include'];
+
 if($^O eq 'solaris')
 {
   if($Config{ptrsize} == 8)
@@ -71,7 +75,6 @@ elsif($^O eq 'linux' && -f '/etc/gentoo-release')
       /usr/share/pkgconfig
     )];
     $status{system_libdir}     = ['/usr/lib64'];
-    $status{system_includedir} = ['/usr/include'];
   }
   else
   {
@@ -79,8 +82,6 @@ elsif($^O eq 'linux' && -f '/etc/gentoo-release')
       /usr/lib/pkgconfig
       /usr/share/pkgconfig
     )];
-    $status{system_libdir}     = ['/usr/lib'];
-    $status{system_includedir} = ['/usr/include'];
   }
 }
 
@@ -191,20 +192,72 @@ elsif($^O eq 'freebsd')
     "/usr/local/libdata/pkgconfig",
     "/usr/libdata/pkgconfig",
   ];
-  $status{system_libdir}     = [
-    "/usr/lib",
-  ];
-  $status{system_includedir} = [
-    "/usr/include",
-  ];
+}
+
+elsif($^O eq 'cygwin')
+{
+  $status{pkg_config_dir}    = [qw(
+    /usr/lib/pkgconfig
+    /usr/share/pkgconfig
+  )];
+}
+
+elsif($^O eq 'MSWin32')
+{
+  if($Config::Config{myuname} =~ /strawberry-perl/)
+  {
+    my($vol, $dir, $file) = File::Spec->splitpath($^X);
+    my @dirs = File::Spec->splitdir($dir);
+    splice @dirs, -3;
+    my $path = (File::Spec->catdir($vol, @dirs, qw( c lib pkgconfig )));
+    $path =~ s{\\}{/}g;
+    $status{pkg_config_dir} = [
+      $path,
+    ];
+    $status{system_libdir}     = [
+      '/mingw/lib', 
+      '/mingw/lib/pkgconfig/../../lib',
+    ];
+    $status{system_includedir} = [
+      '/mingw/include',
+      '/mingw/lib/pkgconfig/../../include',
+    ];
+  }
+  else
+  {
+    die "do not know enough please open ticket: https://github.com/plicease/Alien-pkgconf/issues";
+  }
+}
+
+elsif($^O eq 'netbsd')
+{
+  $status{pkg_config_dir} = [qw(
+    /usr/pkg/lib/pkgconfig
+    /usr/pkg/share/pkgconfig
+    /usr/X11R7/lib/pkgconfig
+    /usr/lib/pkgconfig
+  )];
+}
+
+elsif($^O eq 'openbsd')
+{
+  $status{pkg_config_dir} = [qw(
+    /usr/lib/pkgconfig
+    /usr/local/lib/pkgconfig
+    /usr/local/share/pkgconfig
+    /usr/X11R6/lib/pkgconfig
+    /usr/X11R6/share/pkgconfig
+  )];
 }
 
 else
 {
-  die "do not know enough about this OS to probe for correct paths";
+  die "do not know enough about this OS to probe for correct paths.  Please open a ticket https://github.com/plicease/Alien-pkgconf/issues";
 }
 
-unshift @{ $status{pkg_config_dir} }, File::Spec->catdir(@prefix, 'lib', 'pkgconfig');
+my $my_pkg_config_dir = File::Spec->catdir(@prefix, 'lib', 'pkgconfig');
+$my_pkg_config_dir =~ s{\\}{/}g if $^O eq 'MSWin32';
+unshift @{ $status{pkg_config_dir} }, $my_pkg_config_dir;
 
 mkdir '_alien' unless -d '_alien';
 open my $fh, '>', $status_filename;
